@@ -29,8 +29,19 @@ def cached_distribution_perf():
 def uncached_distribution_perf():
     "uncached distribution"
     import importlib
+
     import importlib_metadata
 
     # end warmup
     importlib.invalidate_caches()
     importlib_metadata.distribution('ipython')
+
+
+def entrypoint_regexp_perf():
+    import re
+
+    import importlib_metadata
+
+    input = '0' + ' ' * 2**10 + '0'  # end warmup
+
+    re.match(importlib_metadata.EntryPoint.pattern, input)
